summaryrefslogtreecommitdiffstats
path: root/konsole/konsole/konsolebookmarkmenu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsole/konsole/konsolebookmarkmenu.cpp')
-rw-r--r--konsole/konsole/konsolebookmarkmenu.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/konsole/konsole/konsolebookmarkmenu.cpp b/konsole/konsole/konsolebookmarkmenu.cpp
index 0afe6a693..d199808df 100644
--- a/konsole/konsole/konsolebookmarkmenu.cpp
+++ b/konsole/konsole/konsolebookmarkmenu.cpp
@@ -36,14 +36,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
/*
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
* They are named differently because the TQT_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?
*/
- disconnect( _parentMenu, TQT_SIGNAL( aboutToShow() ), this,
- TQT_SLOT( slotAboutToShow() ) );
- connect( _parentMenu, TQT_SIGNAL( aboutToShow() ),
- TQT_SLOT( slotAboutToShow2() ) );
+ disconnect( _parentMenu, TQ_SIGNAL( aboutToShow() ), this,
+ TQ_SLOT( slotAboutToShow() ) );
+ connect( _parentMenu, TQ_SIGNAL( aboutToShow() ),
+ TQ_SLOT( slotAboutToShow2() ) );
}
/*
@@ -113,7 +113,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
// kdDebug(1203) << "Creating URL bookmark menu item for " << bm.text() << endl;
// create a normal URL item, with ID as a name
TDEAction * action = new TDEAction( text, bm.icon(), 0,
- this, TQT_SLOT( slotBookmarkSelected() ),
+ this, TQ_SLOT( slotBookmarkSelected() ),
m_actionCollection, bm.url().url().utf8() );
action->setStatusText( bm.url().prettyURL() );
@@ -149,7 +149,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
void KonsoleBookmarkMenu::slotBookmarkSelected()
{
if ( !m_pOwner ) return; // this view doesn't handle bookmarks...
- m_kOwner->openBookmarkURL( TQString::fromUtf8(TQT_TQOBJECT_CONST(sender())->name()), /* URL */
+ m_kOwner->openBookmarkURL( TQString::fromUtf8(sender()->name()), /* URL */
( (TDEAction *)sender() )->text() /* Title */ );
}
@@ -36,14 +36,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
- * They are named differently because the TQT_SLOT() macro thinks we want
+ * They are named differently because the TQ_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?